Module columnar

Module columnar 

Re-exports

pub use column_def::ColumnDef;
pub use column_def::ColumnModifier;
pub use column_parse::ColumnTypeParseError;
pub use column_type::ColumnType;
pub use profile::ColumnarProfile;
pub use profile::DocumentMode;
pub use schema::BITEMPORAL_RESERVED_COLUMNS;
pub use schema::BITEMPORAL_SYSTEM_FROM;
pub use schema::BITEMPORAL_VALID_FROM;
pub use schema::BITEMPORAL_VALID_UNTIL;
pub use schema::ColumnarSchema;
pub use schema::DroppedColumn;
pub use schema::SchemaError;
pub use schema::SchemaOps;
pub use schema::StrictSchema;

Modules

column_def
ColumnDef and ColumnModifier — typed column definitions for strict document and columnar collections.
column_parse
std::fmt::Display and std::str::FromStr for ColumnType, plus ColumnTypeParseError.
column_type
ColumnType — the atomic value type for typed schemas.
profile
ColumnarProfile and DocumentMode — collection storage specializations.
schema
Strict document and columnar schemas with shared operations trait.