ColumnType and ColumnDef — the atomic building blocks of typed schemas.
Structs
- Column
Def - A single column definition in a strict document or columnar schema.
Enums
- Column
Modifier - Column-level modifiers that designate special engine roles.
- Column
Type - Typed column definition for strict document and columnar collections.
- Column
Type Parse Error - Error from parsing a column type string.