#[non_exhaustive]pub struct Hlc {
pub wall_ns: u64,
pub logical: u64,
}Expand description
Hybrid Logical Clock timestamp.
#[non_exhaustive] — a epoch_id discriminant for multi-cluster
logical epochs may be added in a future release.
Wire format note
logical is a 64-bit counter. MessagePack integers decode by value,
so small values serialised by future readers will still deserialise
correctly into this type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.wall_ns: u64Wall-clock component: nanoseconds since the Unix epoch.
logical: u64Logical counter incremented when two events share a wall-clock tick.
Implementations