Module frames

Module frames 

Native protocol request and response frame types.

Structs

ErrorPayload
Error details in a response.
NativeRequest
A request sent from client to server over the native protocol.
NativeResponse
A response sent from server to client over the native protocol.