pub enum HelloErrorCode {
BadMagic,
VersionMismatch,
Malformed,
}Expand description
Error code sent in a HelloErrorFrame when the server rejects a handshake.
Variants
BadMagic
The client sent a frame with an unrecognised magic number.
VersionMismatch
The client’s version range does not overlap with the server’s.
Malformed
The frame was otherwise malformed (truncated, invalid field values, etc.)