#[non_exhaustive]#[repr(u8)]pub enum OpCode {
Show 76 variants
Auth = 1,
Ping = 2,
Status = 3,
PointGet = 16,
PointPut = 17,
PointDelete = 18,
VectorSearch = 19,
RangeScan = 20,
CrdtRead = 21,
CrdtApply = 22,
GraphRagFusion = 23,
AlterCollectionPolicy = 24,
Sql = 32,
Ddl = 33,
Explain = 34,
CopyFrom = 35,
Set = 48,
Show = 49,
Reset = 50,
Begin = 64,
Commit = 65,
Rollback = 66,
GraphHop = 80,
GraphNeighbors = 81,
GraphPath = 82,
GraphSubgraph = 83,
EdgePut = 84,
EdgeDelete = 85,
GraphAlgo = 86,
GraphMatch = 87,
SpatialScan = 25,
TimeseriesScan = 26,
TimeseriesIngest = 27,
TextSearch = 96,
HybridSearch = 97,
VectorBatchInsert = 112,
DocumentBatchInsert = 113,
KvScan = 114,
KvExpire = 115,
KvPersist = 116,
KvGetTtl = 117,
KvBatchGet = 118,
KvBatchPut = 119,
KvFieldGet = 120,
KvFieldSet = 121,
DocumentUpdate = 122,
DocumentScan = 123,
DocumentUpsert = 124,
DocumentBulkUpdate = 125,
DocumentBulkDelete = 126,
VectorInsert = 127,
VectorMultiSearch = 128,
VectorDelete = 129,
ColumnarScan = 130,
ColumnarInsert = 131,
RecursiveScan = 132,
DocumentTruncate = 133,
DocumentEstimateCount = 134,
DocumentInsertSelect = 135,
DocumentRegister = 136,
DocumentDropIndex = 137,
KvRegisterIndex = 138,
KvDropIndex = 139,
KvTruncate = 140,
VectorSetParams = 141,
KvIncr = 142,
KvIncrFloat = 143,
KvCas = 144,
KvGetSet = 145,
KvRegisterSortedIndex = 146,
KvDropSortedIndex = 147,
KvSortedIndexRank = 148,
KvSortedIndexTopK = 149,
KvSortedIndexRange = 150,
KvSortedIndexCount = 151,
KvSortedIndexScore = 152,
}Expand description
Operation codes for the native binary protocol.
Encoded as a single u8 in both the MessagePack frame and JSON frame
(e.g. {"op":3} for Status). The #[serde(try_from = "u8", into = "u8")]
attribute makes JSON encoding consistent with the numeric opcode values.
#[non_exhaustive] — new operation codes may be added as engines grow.
Wire-side unknown-op handling is covered by Unknown(u8);
this attribute adds Rust API hygiene.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Auth = 1
Ping = 2
Status = 3
Report startup/readiness status. Returns the current startup phase and whether the node is healthy. Does not require authentication.
PointGet = 16
PointPut = 17
PointDelete = 18
VectorSearch = 19
RangeScan = 20
CrdtRead = 21
CrdtApply = 22
GraphRagFusion = 23
AlterCollectionPolicy = 24
Sql = 32
Ddl = 33
Explain = 34
CopyFrom = 35
Set = 48
Show = 49
Reset = 50
Begin = 64
Commit = 65
Rollback = 66
GraphHop = 80
GraphNeighbors = 81
GraphPath = 82
GraphSubgraph = 83
EdgePut = 84
EdgeDelete = 85
GraphAlgo = 86
GraphMatch = 87
SpatialScan = 25
TimeseriesScan = 26
TimeseriesIngest = 27
TextSearch = 96
HybridSearch = 97
VectorBatchInsert = 112
DocumentBatchInsert = 113
KvScan = 114
KvExpire = 115
KvPersist = 116
KvGetTtl = 117
KvBatchGet = 118
KvBatchPut = 119
KvFieldGet = 120
KvFieldSet = 121
DocumentUpdate = 122
DocumentScan = 123
DocumentUpsert = 124
DocumentBulkUpdate = 125
DocumentBulkDelete = 126
VectorInsert = 127
VectorMultiSearch = 128
VectorDelete = 129
ColumnarScan = 130
ColumnarInsert = 131
RecursiveScan = 132
DocumentTruncate = 133
DocumentEstimateCount = 134
DocumentInsertSelect = 135
DocumentRegister = 136
DocumentDropIndex = 137
KvRegisterIndex = 138
KvDropIndex = 139
KvTruncate = 140
VectorSetParams = 141
KvIncr = 142
KvIncrFloat = 143
KvCas = 144
KvGetSet = 145
KvRegisterSortedIndex = 146
KvDropSortedIndex = 147
KvSortedIndexRank = 148
KvSortedIndexTopK = 149
KvSortedIndexRange = 150
KvSortedIndexCount = 151
KvSortedIndexScore = 152
Implementations