pub struct ThrottleMsg {
pub throttle: bool,
pub queue_depth: u64,
pub suggested_rate: u64,
}Expand description
Downstream throttle message (client → server, 0x52).
Sent by Lite when its incoming shape delta queue is overwhelmed.
Origin should reduce its push rate for this peer until a
Throttle { throttle: false } is received.
Fields
throttle: booltrue to enable throttling, false to release.
queue_depth: u64Current queue depth at Lite (informational).
suggested_rate: u64Suggested max deltas per second (0 = use server default).