Module column_type

Module column_type 

ColumnType and ColumnDef — the atomic building blocks of typed schemas.

Structs

ColumnDef
A single column definition in a strict document or columnar schema.

Enums

ColumnModifier
Column-level modifiers that designate special engine roles.
ColumnType
Typed column definition for strict document and columnar collections.
ColumnTypeParseError
Error from parsing a column type string.