Storage namespace identifiers for the blob KV store.
Both SQLite (native) and OPFS (WASM) backends use the same namespace scheme to partition data by engine.
Enums
- Archived
Namespace - An archived
Namespace - Namespace
- Storage namespace. Each engine writes to its own namespace in the blob KV store, preventing key collisions.
- Namespace
Resolver - The resolver for an archived
Namespace