Native binary wire protocol types.
Shared between the server (nodedb) and the client (nodedb-client).
All types derive Serialize/Deserialize for MessagePack encoding.
Structs
- Auth
Response - Successful auth response payload.
- Batch
Document - A single document in a batch insert.
- Batch
Vector - A single vector in a batch insert.
- Error
Payload - Error details in a response.
- Native
Request - A request sent from client to server over the native protocol.
- Native
Response - A response sent from server to client over the native protocol.
- Text
Fields - Catch-all text fields used by most operations.
Enums
- Auth
Method - Authentication method in an
Authrequest. - OpCode
- Operation codes for the native binary protocol.
- Request
Fields - Operation-specific request fields.
- Response
Status - Status code in response frames.
Constants
- DEFAULT_
NATIVE_ PORT - Default server port for the native protocol.
- FRAME_
HEADER_ LEN - Length of the frame header (4-byte big-endian u32 payload length).
- MAX_
FRAME_ SIZE - Maximum frame payload size (16 MiB).