Native protocol request and response frame types.
Structs
- Error
Payload - Error details in a response.
- Native
Request - A request sent from client to server over the native protocol.
- Native
Response - A response sent from server to client over the native protocol.