Module violation

Module violation 

Violation types for DLQ classification.

When a sync delta is rejected, the ViolationType categorizes why it was rejected. This is stored in the DLQ on the Origin for forensic review and is separate from CompensationHint (which is what the edge sees).

Enums

ArchivedViolationType
An archived ViolationType
ViolationType
Why a sync delta was placed in the Dead-Letter Queue.
ViolationTypeResolver
The resolver for an archived ViolationType