SyncMessageType

Enum SyncMessageType 

#[non_exhaustive]
#[repr(u8)]
pub enum SyncMessageType {
Show 44 variants Handshake = 1, HandshakeAck = 2, DeltaPush = 16, DeltaAck = 17, DeltaReject = 18, CollectionPurged = 20, ShapeSubscribe = 32, ShapeSnapshot = 33, ShapeDelta = 34, ShapeUnsubscribe = 35, VectorClockSync = 48, TimeseriesPush = 64, TimeseriesAck = 65, ResyncRequest = 80, Throttle = 82, TokenRefresh = 96, TokenRefreshAck = 97, DefinitionSync = 112, PresenceUpdate = 128, PresenceBroadcast = 129, PresenceLeave = 130, ArrayDelta = 144, ArrayDeltaBatch = 145, ArraySnapshot = 146, ArraySnapshotChunk = 147, ArraySchema = 148, ArrayAck = 149, ArrayReject = 150, ArrayCatchupRequest = 151, ColumnarInsert = 160, ColumnarInsertAck = 161, VectorInsert = 162, VectorInsertAck = 163, VectorDelete = 164, VectorDeleteAck = 165, FtsIndex = 166, FtsIndexAck = 167, FtsDelete = 168, FtsDeleteAck = 169, SpatialInsert = 170, SpatialInsertAck = 171, SpatialDelete = 172, SpatialDeleteAck = 173, PingPong = 255,
}
Sync message type identifiers.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Handshake = 1



HandshakeAck = 2



DeltaPush = 16



DeltaAck = 17



DeltaReject = 18



CollectionPurged = 20

Collection purged notification (server → client, 0x14). Sent when an Origin collection is hard-deleted (UNDROP window expired or explicit DROP COLLECTION ... PURGE). The client must drop local Loro state and remove the collection’s redb record; future deltas for the collection are not sync-eligible.



ShapeSubscribe = 32



ShapeSnapshot = 33



ShapeDelta = 34



ShapeUnsubscribe = 35



VectorClockSync = 48



TimeseriesPush = 64

Timeseries metric batch push (client → server, 0x40).



TimeseriesAck = 65

Timeseries push acknowledgment (server → client, 0x41).



ResyncRequest = 80

Re-sync request (bidirectional, 0x50). Sent when sequence gaps or checksum failures are detected.



Throttle = 82

Downstream throttle (client → server, 0x52). Sent when Lite’s incoming queue is overwhelmed.



TokenRefresh = 96

Token refresh request (client → server, 0x60).



TokenRefreshAck = 97

Token refresh acknowledgment (server → client, 0x61).



DefinitionSync = 112

Definition sync (server → client, 0x70). Carries function/trigger/procedure definitions from Origin to Lite.



PresenceUpdate = 128

Presence update (client → server, 0x80).



PresenceBroadcast = 129

Presence broadcast (server → all subscribers except sender, 0x81).



PresenceLeave = 130

Presence leave (server → all subscribers, 0x82).



ArrayDelta = 144

Array CRDT delta (single op, client → server, 0x90).



ArrayDeltaBatch = 145

Array CRDT delta batch (multiple ops, client → server, 0x91).



ArraySnapshot = 146

Array snapshot header (server → client, 0x92).



ArraySnapshotChunk = 147

Array snapshot chunk (server → client, 0x93).



ArraySchema = 148

Array schema CRDT sync (bidirectional, 0x94).



ArrayAck = 149

Array ack — advances GC frontier (client → server, 0x95).



ArrayReject = 150

Array reject (server → client, 0x96). Compensation hint.



ArrayCatchupRequest = 151

Array catchup request (client → server, 0x97).



ColumnarInsert = 160

Columnar batch insert (client → server, 0xA0).



ColumnarInsertAck = 161

Columnar insert acknowledgment (server → client, 0xA1).



VectorInsert = 162

Vector insert (client → server, 0xA2).



VectorInsertAck = 163

Vector insert acknowledgment (server → client, 0xA3).



VectorDelete = 164

Vector delete (client → server, 0xA4).



VectorDeleteAck = 165

Vector delete acknowledgment (server → client, 0xA5).



FtsIndex = 166

FTS document index (client → server, 0xA6).



FtsIndexAck = 167

FTS index acknowledgment (server → client, 0xA7).



FtsDelete = 168

FTS document delete (client → server, 0xA8).



FtsDeleteAck = 169

FTS delete acknowledgment (server → client, 0xA9).



SpatialInsert = 170

Spatial geometry insert (client → server, 0xAA).



SpatialInsertAck = 171

Spatial insert acknowledgment (server → client, 0xAB).



SpatialDelete = 172

Spatial geometry delete (client → server, 0xAC).



SpatialDeleteAck = 173

Spatial delete acknowledgment (server → client, 0xAD).



PingPong = 255

Implementations